ignore

package module
v1.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 25, 2019 License: MIT Imports: 0 Imported by: 2

README

ignore

Godoc Report Tests Coverage Sponsor

Ignore certain parts of a string when parsing.

Documentation

The tests provide enough documentation.

Style

Please take a look at the style guidelines if you'd like to make a pull request.

Sponsors

Cedric Fung Scott Rayapoullé Eduard Urbach
Cedric Fung Scott Rayapoullé Eduard Urbach

Want to see your own name here?

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Reader

type Reader struct {
	// contains filtered or unexported fields
}

Reader is a reader that can ignore runes.

func (*Reader) CanIgnore

func (r *Reader) CanIgnore(letter rune) bool

CanIgnore tells you if you can ignore the rune.

Jump to